@@ -6,8 +6,9 @@ use actix_web::{
 
 use crate::actix_web_error::{ActixWebError, ErrorInfo};
 
+/// transform json playload error to actix error
 pub fn json_error_handler(err: JsonPayloadError, _req: &HttpRequest) -> Error {
-    let awe = ActixWebError {
+    let actix_web_error = ActixWebError {
         error_info: ErrorInfo {
             message: "Invalid json body".to_string(),
             explaination: Some(err.to_string()),
@@ -16,5 +17,5 @@ pub fn json_error_handler(err: JsonPayloadError, _req: &HttpRequest) -> Error {
         status_code: StatusCode::BAD_REQUEST,
     };
 
-    awe.to_error()
+    actix_web_error.to_error()
 }
